@@ -2,7 +2,7 @@ package RapidApp;
 use strict;
 use warnings;
 
-our $VERSION = '0.99031';
+our $VERSION = '0.99100';
 
 use Carp::Clan;
 
@@ -26,6 +26,12 @@ our $ACTIVE_REQUEST_CONTEXT = undef;
 
 sub active_request_context { $ACTIVE_REQUEST_CONTEXT }
 
+
+
+# Private - will be removed in the future:
+our $ROOT_MODULE_INSTANCE = undef;
+sub _rootModule { $ROOT_MODULE_INSTANCE }
+
 1;
 
 
